pub struct NewCommit {
pub parent_ids: Vec<String>,
pub message: String,
pub author: String,
pub email: String,
pub timestamp: OffsetDateTime,
}Expand description
NewCommit is to be used when creating a new Commit, but we don’t know the id yet because we need to hash the contents
Fields
parent_ids: Vec<String>message: Stringemail: Stringtimestamp: OffsetDateTimeImplementations